==> box64_0.2.6+dfsg.orig.tar.xz: box64-0.2.6/src/wrapped/wrappedlibxcbicccm_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_icccm_get_text_property, 
//GO(xcb_icccm_get_text_property_reply, 
//GO(xcb_icccm_get_text_property_reply_wipe, 
//GO(xcb_icccm_get_text_property_unchecked, 
//GO(xcb_icccm_get_wm_class, 
//GO(xcb_icccm_get_wm_class_from_reply, 
//GO(xcb_icccm_get_wm_class_reply, 
//GO(xcb_icccm_get_wm_class_reply_wipe, 
//GO(xcb_icccm_get_wm_class_unchecked, 
//GO(xcb_icccm_get_wm_client_machine, 
//GO(xcb_icccm_get_wm_client_machine_reply, 
//GO(xcb_icccm_get_wm_client_machine_unchecked, 
//GO(xcb_icccm_get_wm_colormap_windows, 
//GO(xcb_icccm_get_wm_colormap_windows_from_reply, 
//GO(xcb_icccm_get_wm_colormap_windows_reply, 
//GO(xcb_icccm_get_wm_colormap_windows_reply_wipe, 
//GO(xcb_icccm_get_wm_colormap_windows_unchecked, 
//GO(xcb_icccm_get_wm_hints, 
//GO(xcb_icccm_get_wm_hints_from_reply, 
GO(xcb_icccm_get_wm_hints_reply, CFpupp)
GO(xcb_icccm_get_wm_hints_unchecked, pFppu)
//GO(xcb_icccm_get_wm_icon_name, 
//GO(xcb_icccm_get_wm_icon_name_reply, 
//GO(xcb_icccm_get_wm_icon_name_unchecked, 
//GO(xcb_icccm_get_wm_name, 
//GO(xcb_icccm_get_wm_name_reply, 
//GO(xcb_icccm_get_wm_name_unchecked, 
//GO(xcb_icccm_get_wm_normal_hints, 
//GO(xcb_icccm_get_wm_normal_hints_reply, 
//GO(xcb_icccm_get_wm_normal_hints_unchecked, 
//GO(xcb_icccm_get_wm_protocols, 
//GO(xcb_icccm_get_wm_protocols_from_reply, 
//GO(xcb_icccm_get_wm_protocols_reply, 
//GO(xcb_icccm_get_wm_protocols_reply_wipe, 
//GO(xcb_icccm_get_wm_protocols_unchecked, 
//GO(xcb_icccm_get_wm_size_hints, 
//GO(xcb_icccm_get_wm_size_hints_from_reply, 
//GO(xcb_icccm_get_wm_size_hints_reply, 
//GO(xcb_icccm_get_wm_size_hints_unchecked, 
//GO(xcb_icccm_get_wm_transient_for, 
//GO(xcb_icccm_get_wm_transient_for_from_reply, 
//GO(xcb_icccm_get_wm_transient_for_reply, 
//GO(xcb_icccm_get_wm_transient_for_unchecked, 
//GO(xcb_icccm_set_wm_class, 
//GO(xcb_icccm_set_wm_class_checked, 
//GO(xcb_icccm_set_wm_client_machine, 
//GO(xcb_icccm_set_wm_client_machine_checked, 
//GO(xcb_icccm_set_wm_colormap_windows, 
//GO(xcb_icccm_set_wm_colormap_windows_checked, 
GO(xcb_icccm_set_wm_hints, pFppup)
GO(xcb_icccm_set_wm_hints_checked, pFppup)
//GO(xcb_icccm_set_wm_icon_name, 
//GO(xcb_icccm_set_wm_icon_name_checked, 
//GO(xcb_icccm_set_wm_name, 
//GO(xcb_icccm_set_wm_name_checked, 
GO(xcb_icccm_set_wm_normal_hints, pFppup)
GO(xcb_icccm_set_wm_normal_hints_checked, pFppup)
//GO(xcb_icccm_set_wm_protocols, 
//GO(xcb_icccm_set_wm_protocols_checked, 
//GO(xcb_icccm_set_wm_size_hints, 
//GO(xcb_icccm_set_wm_size_hints_checked, 
//GO(xcb_icccm_set_wm_transient_for, 
//GO(xcb_icccm_set_wm_transient_for_checked, 
//GO(xcb_icccm_size_hints_set_aspect, 
GO(xcb_icccm_size_hints_set_base_size, vFpii)
GO(xcb_icccm_size_hints_set_max_size, vFpii)
GO(xcb_icccm_size_hints_set_min_size, vFpii)
GO(xcb_icccm_size_hints_set_position, vFpiii)
GO(xcb_icccm_size_hints_set_resize_inc, vFpii)
GO(xcb_icccm_size_hints_set_size, vFpiii)
GO(xcb_icccm_size_hints_set_win_gravity, vFpi)
//GO(xcb_icccm_wm_hints_get_urgency, 
GO(xcb_icccm_wm_hints_set_iconic, vFp)
//GO(xcb_icccm_wm_hints_set_icon_mask, 
//GO(xcb_icccm_wm_hints_set_icon_pixmap, 
//GO(xcb_icccm_wm_hints_set_icon_window, 
GO(xcb_icccm_wm_hints_set_input, vFpC)
//GO(xcb_icccm_wm_hints_set_none, 
GO(xcb_icccm_wm_hints_set_normal, vFp)
//GO(xcb_icccm_wm_hints_set_urgency, 
//GO(xcb_icccm_wm_hints_set_window_group, 
//GO(xcb_icccm_wm_hints_set_withdrawn,

==> box64_0.3.0+dfsg.orig.tar.xz: box64-0.3.0/src/wrapped/wrappedlibxcbicccm_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_icccm_get_text_property, 
//GO(xcb_icccm_get_text_property_reply, 
//GO(xcb_icccm_get_text_property_reply_wipe, 
//GO(xcb_icccm_get_text_property_unchecked, 
//GO(xcb_icccm_get_wm_class, 
//GO(xcb_icccm_get_wm_class_from_reply, 
//GO(xcb_icccm_get_wm_class_reply, 
//GO(xcb_icccm_get_wm_class_reply_wipe, 
//GO(xcb_icccm_get_wm_class_unchecked, 
//GO(xcb_icccm_get_wm_client_machine, 
//GO(xcb_icccm_get_wm_client_machine_reply, 
//GO(xcb_icccm_get_wm_client_machine_unchecked, 
//GO(xcb_icccm_get_wm_colormap_windows, 
//GO(xcb_icccm_get_wm_colormap_windows_from_reply, 
//GO(xcb_icccm_get_wm_colormap_windows_reply, 
//GO(xcb_icccm_get_wm_colormap_windows_reply_wipe, 
//GO(xcb_icccm_get_wm_colormap_windows_unchecked, 
GO(xcb_icccm_get_wm_hints, uFbu)
//GO(xcb_icccm_get_wm_hints_from_reply, 
GO(xcb_icccm_get_wm_hints_reply, CFbupp)
GO(xcb_icccm_get_wm_hints_unchecked, uFbu)
//GO(xcb_icccm_get_wm_icon_name, 
//GO(xcb_icccm_get_wm_icon_name_reply, 
//GO(xcb_icccm_get_wm_icon_name_unchecked, 
//GO(xcb_icccm_get_wm_name, 
//GO(xcb_icccm_get_wm_name_reply, 
//GO(xcb_icccm_get_wm_name_unchecked, 
//GO(xcb_icccm_get_wm_normal_hints, 
//GO(xcb_icccm_get_wm_normal_hints_reply, 
//GO(xcb_icccm_get_wm_normal_hints_unchecked, 
//GO(xcb_icccm_get_wm_protocols, 
//GO(xcb_icccm_get_wm_protocols_from_reply, 
//GO(xcb_icccm_get_wm_protocols_reply, 
//GO(xcb_icccm_get_wm_protocols_reply_wipe, 
//GO(xcb_icccm_get_wm_protocols_unchecked, 
//GO(xcb_icccm_get_wm_size_hints, 
//GO(xcb_icccm_get_wm_size_hints_from_reply, 
//GO(xcb_icccm_get_wm_size_hints_reply, 
//GO(xcb_icccm_get_wm_size_hints_unchecked, 
//GO(xcb_icccm_get_wm_transient_for, 
//GO(xcb_icccm_get_wm_transient_for_from_reply, 
//GO(xcb_icccm_get_wm_transient_for_reply, 
//GO(xcb_icccm_get_wm_transient_for_unchecked, 
//GO(xcb_icccm_set_wm_class, 
//GO(xcb_icccm_set_wm_class_checked, 
//GO(xcb_icccm_set_wm_client_machine, 
//GO(xcb_icccm_set_wm_client_machine_checked, 
//GO(xcb_icccm_set_wm_colormap_windows, 
//GO(xcb_icccm_set_wm_colormap_windows_checked, 
GO(xcb_icccm_set_wm_hints, uFbup)
GO(xcb_icccm_set_wm_hints_checked, uFbup)
//GO(xcb_icccm_set_wm_icon_name, 
//GO(xcb_icccm_set_wm_icon_name_checked, 
//GO(xcb_icccm_set_wm_name, 
//GO(xcb_icccm_set_wm_name_checked, 
GO(xcb_icccm_set_wm_normal_hints, uFbup)
GO(xcb_icccm_set_wm_normal_hints_checked, uFbup)
//GO(xcb_icccm_set_wm_protocols, 
//GO(xcb_icccm_set_wm_protocols_checked, 
//GO(xcb_icccm_set_wm_size_hints, 
//GO(xcb_icccm_set_wm_size_hints_checked, 
//GO(xcb_icccm_set_wm_transient_for, 
//GO(xcb_icccm_set_wm_transient_for_checked, 
//GO(xcb_icccm_size_hints_set_aspect, 
GO(xcb_icccm_size_hints_set_base_size, vFpii)
GO(xcb_icccm_size_hints_set_max_size, vFpii)
GO(xcb_icccm_size_hints_set_min_size, vFpii)
GO(xcb_icccm_size_hints_set_position, vFpiii)
GO(xcb_icccm_size_hints_set_resize_inc, vFpii)
GO(xcb_icccm_size_hints_set_size, vFpiii)
GO(xcb_icccm_size_hints_set_win_gravity, vFpi)
//GO(xcb_icccm_wm_hints_get_urgency, 
GO(xcb_icccm_wm_hints_set_iconic, vFp)
//GO(xcb_icccm_wm_hints_set_icon_mask, 
//GO(xcb_icccm_wm_hints_set_icon_pixmap, 
//GO(xcb_icccm_wm_hints_set_icon_window, 
GO(xcb_icccm_wm_hints_set_input, vFpC)
//GO(xcb_icccm_wm_hints_set_none, 
GO(xcb_icccm_wm_hints_set_normal, vFp)
//GO(xcb_icccm_wm_hints_set_urgency, 
//GO(xcb_icccm_wm_hints_set_window_group, 
//GO(xcb_icccm_wm_hints_set_withdrawn,
